@@ -33,7 +33,7 @@
 #include "kpTool.h"
 #include "kpToolPrivate.h"
 
-#include <limits.h>
+#include <climits>
 
 #include <kactioncollection.h>
 #include "kpLogCategories.h"
@@ -61,9 +61,12 @@ kpTool::kpTool(const QString &text, const QString &description,
     d->key = key;
     d->action = nullptr;
     d->ignoreColorSignals = 0;
-    d->shiftPressed = false, d->controlPressed = false, d->altPressed = false;  // set in beginInternal()
+    d->shiftPressed = false;
+    d->controlPressed = false;
+    d->altPressed = false;  // set in beginInternal()
     d->beganDraw = false;
-    d->text = text, d->description = description;
+    d->text = text;
+    d->description = description;
     d->began = false;
     d->viewUnderStartPoint = nullptr;
     d->userShapeStartPoint = KP_INVALID_POINT;
@@ -81,8 +84,9 @@ kpTool::kpTool(const QString &text, const QString &description,
 kpTool::~kpTool ()
 {
     // before destructing, stop using the tool
-    if (d->began)
+    if (d->began) {
         endInternal ();
+    }
 
     delete d->action;
 
@@ -106,7 +110,7 @@ void kpTool::initAction ()
 
     d->action->setWhatsThis(d->description);
 
-    connect(d->action, SIGNAL(changed()), this, SIGNAL (actionToolTipChanged()));
+    connect (d->action, &kpToolAction::changed, this, &kpTool::actionToolTipChanged);
 }
 
 //---------------------------------------------------------------------
@@ -122,7 +126,7 @@ QString kpTool::text () const
 static bool KeyIsText (int key)
 {
     // TODO: should work like !QKeyEvent::text().isEmpty()
-    return !(key & (Qt::KeyboardModifierMask ^ Qt::ShiftModifier));
+    return !(static_cast<unsigned int> (key) & (Qt::KeyboardModifierMask ^ Qt::ShiftModifier));
 }
 
 //---------------------------------------------------------------------
@@ -131,11 +135,11 @@ static bool KeyIsText (int key)
 QString kpTool::toolTipForTextAndShortcut (const QString &text,
                                            const QList<QKeySequence> &shortcut)
 {
-    foreach(const QKeySequence &seq, shortcut)
+    for(const auto &seq : shortcut)
     {
-        if (seq.count () == 1 && ::KeyIsText (seq [0]))
-            return i18nc ("<Tool Name> (<Single Accel Key>)",
-                          "%1 (%2)", text, seq.toString ().toUpper ());
+        if (seq.count () == 1 && ::KeyIsText (seq [0])) {
+            return i18nc ("<Tool Name> (<Single Accel Key>)", "%1 (%2)", text, seq.toString ().toUpper ());
+        }
     }
 
     return text;
@@ -160,7 +164,7 @@ QList<QKeySequence> kpTool::shortcutForKey (int key)
         shortcut.append (QKeySequence (key));
         // (CTRL+<key>, ALT+<key>, CTRL+ALT+<key>, CTRL+SHIFT+<key>
         //  all clash with global KDE shortcuts)
-        shortcut.append (QKeySequence (Qt::ALT + Qt::SHIFT + key));
+        shortcut.append (QKeySequence (static_cast<int>(Qt::ALT) + static_cast<int>(Qt::SHIFT) + key));
     }
 
     return shortcut;
